/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.admin.directory.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * JSON template for User object in Apps Directory API.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Admin Directory API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class User extends GenericJson {

  /**
   * Addresses of User
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<UserAddress> addresses;

  static {
    // hack to force ProGuard to consider UserAddress used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(UserAddress.class);
  }

  /**
   * Indicates if user has agreed to terms (Read-only)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean agreedToTerms;

  /**
   * List of aliases (Read-only)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> aliases;

  /**
   * Boolean indicating if the user should change password in next login
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean changePasswordAtNextLogin;

  /**
   * User's Google account creation time. (Read-only)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime creationTime;

  /**
   * CustomerId of User (Read-only)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String customerId;

  /**
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime deletionTime;

  /**
   * Emails of User
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<UserEmail> emails;

  static {
    // hack to force ProGuard to consider UserEmail used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(UserEmail.class);
  }

  /**
   * The external Ids of User *
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<UserExternalId> externalIds;

  static {
    // hack to force ProGuard to consider UserExternalId used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(UserExternalId.class);
  }

  /**
   * Hash function name for password. Supported are MD5, SHA-1 and crypt
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String hashFunction;

  /**
   * Unique identifier of User (Read-only)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * User's Instant Messenger
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<UserIm> ims;

  static {
    // hack to force ProGuard to consider UserIm used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(UserIm.class);
  }

  /**
   * Boolean indicating if user is included in Global Address List
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean includeInGlobalAddressList;

  /**
   * Boolean indicating if ip is whitelisted
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean ipWhitelisted;

  /**
   * Boolean indicating if the user is admin (Read-only)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isAdmin;

  /**
   * Boolean indicating if the user is delegated admin (Read-only)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isDelegatedAdmin;

  /**
   * Is mailbox setup (Read-only)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isMailboxSetup;

  /**
   * Kind of resource this is.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * User's last login time. (Read-only)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime lastLoginTime;

  /**
   * User's name
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private UserName name;

  /**
   * List of non editable aliases (Read-only)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> nonEditableAliases;

  /**
   * OrgUnit of User
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String orgUnitPath;

  /**
   * Organizations of User
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<UserOrganization> organizations;

  static {
    // hack to force ProGuard to consider UserOrganization used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(UserOrganization.class);
  }

  /**
   * User's password
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String password;

  /**
   * Phone numbers of User
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<UserPhone> phones;

  static {
    // hack to force ProGuard to consider UserPhone used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(UserPhone.class);
  }

  /**
   * username of User
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String primaryEmail;

  /**
   * The Relations of User *
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<UserRelation> relations;

  static {
    // hack to force ProGuard to consider UserRelation used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(UserRelation.class);
  }

  /**
   * Indicates if user is suspended
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean suspended;

  /**
   * Suspension reason if user is suspended (Read-only)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String suspensionReason;

  /**
   * Photo Url of the user (Read-only)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String thumbnailPhotoUrl;

  /**
   * Addresses of User
   * The value returned may be {@code null}.
   */
  public java.util.List<UserAddress> getAddresses() {
    return addresses;
  }

  /**
   * Addresses of User
   * The value set may be {@code null}.
   */
  public User setAddresses(java.util.List<UserAddress> addresses) {
    this.addresses = addresses;
    return this;
  }

  /**
   * Indicates if user has agreed to terms (Read-only)
   * The value returned may be {@code null}.
   */
  public Boolean getAgreedToTerms() {
    return agreedToTerms;
  }

  /**
   * Indicates if user has agreed to terms (Read-only)
   * The value set may be {@code null}.
   */
  public User setAgreedToTerms(Boolean agreedToTerms) {
    this.agreedToTerms = agreedToTerms;
    return this;
  }

  /**
   * List of aliases (Read-only)
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getAliases() {
    return aliases;
  }

  /**
   * List of aliases (Read-only)
   * The value set may be {@code null}.
   */
  public User setAliases(java.util.List<String> aliases) {
    this.aliases = aliases;
    return this;
  }

  /**
   * Boolean indicating if the user should change password in next login
   * The value returned may be {@code null}.
   */
  public Boolean getChangePasswordAtNextLogin() {
    return changePasswordAtNextLogin;
  }

  /**
   * Boolean indicating if the user should change password in next login
   * The value set may be {@code null}.
   */
  public User setChangePasswordAtNextLogin(Boolean changePasswordAtNextLogin) {
    this.changePasswordAtNextLogin = changePasswordAtNextLogin;
    return this;
  }

  /**
   * User's Google account creation time. (Read-only)
   * The value returned may be {@code null}.
   */
  public DateTime getCreationTime() {
    return creationTime;
  }

  /**
   * User's Google account creation time. (Read-only)
   * The value set may be {@code null}.
   */
  public User setCreationTime(DateTime creationTime) {
    this.creationTime = creationTime;
    return this;
  }

  /**
   * CustomerId of User (Read-only)
   * The value returned may be {@code null}.
   */
  public String getCustomerId() {
    return customerId;
  }

  /**
   * CustomerId of User (Read-only)
   * The value set may be {@code null}.
   */
  public User setCustomerId(String customerId) {
    this.customerId = customerId;
    return this;
  }

  /**

   * The value returned may be {@code null}.
   */
  public DateTime getDeletionTime() {
    return deletionTime;
  }

  /**

   * The value set may be {@code null}.
   */
  public User setDeletionTime(DateTime deletionTime) {
    this.deletionTime = deletionTime;
    return this;
  }

  /**
   * Emails of User
   * The value returned may be {@code null}.
   */
  public java.util.List<UserEmail> getEmails() {
    return emails;
  }

  /**
   * Emails of User
   * The value set may be {@code null}.
   */
  public User setEmails(java.util.List<UserEmail> emails) {
    this.emails = emails;
    return this;
  }

  /**
   * The external Ids of User *
   * The value returned may be {@code null}.
   */
  public java.util.List<UserExternalId> getExternalIds() {
    return externalIds;
  }

  /**
   * The external Ids of User *
   * The value set may be {@code null}.
   */
  public User setExternalIds(java.util.List<UserExternalId> externalIds) {
    this.externalIds = externalIds;
    return this;
  }

  /**
   * Hash function name for password. Supported are MD5, SHA-1 and crypt
   * The value returned may be {@code null}.
   */
  public String getHashFunction() {
    return hashFunction;
  }

  /**
   * Hash function name for password. Supported are MD5, SHA-1 and crypt
   * The value set may be {@code null}.
   */
  public User setHashFunction(String hashFunction) {
    this.hashFunction = hashFunction;
    return this;
  }

  /**
   * Unique identifier of User (Read-only)
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Unique identifier of User (Read-only)
   * The value set may be {@code null}.
   */
  public User setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * User's Instant Messenger
   * The value returned may be {@code null}.
   */
  public java.util.List<UserIm> getIms() {
    return ims;
  }

  /**
   * User's Instant Messenger
   * The value set may be {@code null}.
   */
  public User setIms(java.util.List<UserIm> ims) {
    this.ims = ims;
    return this;
  }

  /**
   * Boolean indicating if user is included in Global Address List
   * The value returned may be {@code null}.
   */
  public Boolean getIncludeInGlobalAddressList() {
    return includeInGlobalAddressList;
  }

  /**
   * Boolean indicating if user is included in Global Address List
   * The value set may be {@code null}.
   */
  public User setIncludeInGlobalAddressList(Boolean includeInGlobalAddressList) {
    this.includeInGlobalAddressList = includeInGlobalAddressList;
    return this;
  }

  /**
   * Boolean indicating if ip is whitelisted
   * The value returned may be {@code null}.
   */
  public Boolean getIpWhitelisted() {
    return ipWhitelisted;
  }

  /**
   * Boolean indicating if ip is whitelisted
   * The value set may be {@code null}.
   */
  public User setIpWhitelisted(Boolean ipWhitelisted) {
    this.ipWhitelisted = ipWhitelisted;
    return this;
  }

  /**
   * Boolean indicating if the user is admin (Read-only)
   * The value returned may be {@code null}.
   */
  public Boolean getIsAdmin() {
    return isAdmin;
  }

  /**
   * Boolean indicating if the user is admin (Read-only)
   * The value set may be {@code null}.
   */
  public User setIsAdmin(Boolean isAdmin) {
    this.isAdmin = isAdmin;
    return this;
  }

  /**
   * Boolean indicating if the user is delegated admin (Read-only)
   * The value returned may be {@code null}.
   */
  public Boolean getIsDelegatedAdmin() {
    return isDelegatedAdmin;
  }

  /**
   * Boolean indicating if the user is delegated admin (Read-only)
   * The value set may be {@code null}.
   */
  public User setIsDelegatedAdmin(Boolean isDelegatedAdmin) {
    this.isDelegatedAdmin = isDelegatedAdmin;
    return this;
  }

  /**
   * Is mailbox setup (Read-only)
   * The value returned may be {@code null}.
   */
  public Boolean getIsMailboxSetup() {
    return isMailboxSetup;
  }

  /**
   * Is mailbox setup (Read-only)
   * The value set may be {@code null}.
   */
  public User setIsMailboxSetup(Boolean isMailboxSetup) {
    this.isMailboxSetup = isMailboxSetup;
    return this;
  }

  /**
   * Kind of resource this is.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Kind of resource this is.
   * The value set may be {@code null}.
   */
  public User setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * User's last login time. (Read-only)
   * The value returned may be {@code null}.
   */
  public DateTime getLastLoginTime() {
    return lastLoginTime;
  }

  /**
   * User's last login time. (Read-only)
   * The value set may be {@code null}.
   */
  public User setLastLoginTime(DateTime lastLoginTime) {
    this.lastLoginTime = lastLoginTime;
    return this;
  }

  /**
   * User's name
   * The value returned may be {@code null}.
   */
  public UserName getName() {
    return name;
  }

  /**
   * User's name
   * The value set may be {@code null}.
   */
  public User setName(UserName name) {
    this.name = name;
    return this;
  }

  /**
   * List of non editable aliases (Read-only)
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getNonEditableAliases() {
    return nonEditableAliases;
  }

  /**
   * List of non editable aliases (Read-only)
   * The value set may be {@code null}.
   */
  public User setNonEditableAliases(java.util.List<String> nonEditableAliases) {
    this.nonEditableAliases = nonEditableAliases;
    return this;
  }

  /**
   * OrgUnit of User
   * The value returned may be {@code null}.
   */
  public String getOrgUnitPath() {
    return orgUnitPath;
  }

  /**
   * OrgUnit of User
   * The value set may be {@code null}.
   */
  public User setOrgUnitPath(String orgUnitPath) {
    this.orgUnitPath = orgUnitPath;
    return this;
  }

  /**
   * Organizations of User
   * The value returned may be {@code null}.
   */
  public java.util.List<UserOrganization> getOrganizations() {
    return organizations;
  }

  /**
   * Organizations of User
   * The value set may be {@code null}.
   */
  public User setOrganizations(java.util.List<UserOrganization> organizations) {
    this.organizations = organizations;
    return this;
  }

  /**
   * User's password
   * The value returned may be {@code null}.
   */
  public String getPassword() {
    return password;
  }

  /**
   * User's password
   * The value set may be {@code null}.
   */
  public User setPassword(String password) {
    this.password = password;
    return this;
  }

  /**
   * Phone numbers of User
   * The value returned may be {@code null}.
   */
  public java.util.List<UserPhone> getPhones() {
    return phones;
  }

  /**
   * Phone numbers of User
   * The value set may be {@code null}.
   */
  public User setPhones(java.util.List<UserPhone> phones) {
    this.phones = phones;
    return this;
  }

  /**
   * username of User
   * The value returned may be {@code null}.
   */
  public String getPrimaryEmail() {
    return primaryEmail;
  }

  /**
   * username of User
   * The value set may be {@code null}.
   */
  public User setPrimaryEmail(String primaryEmail) {
    this.primaryEmail = primaryEmail;
    return this;
  }

  /**
   * The Relations of User *
   * The value returned may be {@code null}.
   */
  public java.util.List<UserRelation> getRelations() {
    return relations;
  }

  /**
   * The Relations of User *
   * The value set may be {@code null}.
   */
  public User setRelations(java.util.List<UserRelation> relations) {
    this.relations = relations;
    return this;
  }

  /**
   * Indicates if user is suspended
   * The value returned may be {@code null}.
   */
  public Boolean getSuspended() {
    return suspended;
  }

  /**
   * Indicates if user is suspended
   * The value set may be {@code null}.
   */
  public User setSuspended(Boolean suspended) {
    this.suspended = suspended;
    return this;
  }

  /**
   * Suspension reason if user is suspended (Read-only)
   * The value returned may be {@code null}.
   */
  public String getSuspensionReason() {
    return suspensionReason;
  }

  /**
   * Suspension reason if user is suspended (Read-only)
   * The value set may be {@code null}.
   */
  public User setSuspensionReason(String suspensionReason) {
    this.suspensionReason = suspensionReason;
    return this;
  }

  /**
   * Photo Url of the user (Read-only)
   * The value returned may be {@code null}.
   */
  public String getThumbnailPhotoUrl() {
    return thumbnailPhotoUrl;
  }

  /**
   * Photo Url of the user (Read-only)
   * The value set may be {@code null}.
   */
  public User setThumbnailPhotoUrl(String thumbnailPhotoUrl) {
    this.thumbnailPhotoUrl = thumbnailPhotoUrl;
    return this;
  }

}
